@@ -12,7 +12,57 @@ var score = 0;
 var dropBombChance = 2; //start chance of and alien dropping a bomb
 
 var level = 0;
-var lives = 3; //Edit this to cheat!
+var startlives = 3; //Edit this to cheat!
+var livesindication = new Array(startlives - 1);
+var lives;
+
+function createLivesIndication() {
+    var px = 0;
+    var py = 0;
+
+    py = board.height - ship.height;
+
+    for (var i = 0; i < startlives-1; ++i) {
+        px = i * (ship.width + 20);
+
+        var component = Qt.createComponent("Ship.qml");
+        livesindication[i] = component.createObject(board);
+
+        if ( livesindication[i] == null) {
+            // Error Handling
+            console.log("Error creating life ship");
+        }
+        if (livesindication[i]) {
+                livesindication[i].x = px;
+                livesindication[i].y = py;
+        }
+
+    }
+}
+
+function destroyLivesIndication() {
+    for (var i = 0; i < startlives-1; ++i) {
+        if(livesindication[i]) {
+            livesinidication[i].destroy();
+            livesindication[i] = null;
+        }
+    }
+}
+
+function shipHit() {
+    destroyShipSound.play();
+    if (lives > 1) {
+        lives--;
+        if (livesindication[lives - 1]) {
+            livesindication[lives - 1].destroy();
+            livesindication[lives - 1] = null
+            lifelosttimer.start();
+        }
+
+    } else { //game over
+        endGame(true);
+    }
+}
 
 //Load the bullet QML and position it at the centre of the ship
 function createBullet() {
@@ -39,6 +89,9 @@ function createBullet() {
         if (Settings.FlashOnFire == "TRUE") {
             flashanim.start();
         }
+        console.log(shootSound.status);
+
+        shootSound.play();
         bullet.x = ship.x + ship.width/2 - bullet.width/2;
         bullet.y = ship.y
     }
@@ -126,6 +179,10 @@ function startGame()
         //Reset the alien speed and chance of dropping a bomb
         alienanimation.interval = 600;
         dropBombChance = 100;
+
+        lives = startlives;
+        destroyLivesIndication();
+        createLivesIndication();
     }
 
     //Hide the seetings button when the game starts
@@ -287,6 +344,7 @@ function checkBulletAlienCollision() {
         if (bullet && aliens[i]) { //Check if objects exist first
             if (bullet.x > aliens[i].x && bullet.x < aliens[i].x + aliens[i].width) {
                 if (bullet.y > aliens[i].y && bullet.y < aliens[i].y + aliens[i].height) {
+                    destroyAlienSound.play();
                     aliens[i].destroy();
                     aliens[i] = null;
                     score += 100;
@@ -311,7 +369,7 @@ function checkBombShipCollision() {
                 if (bombs[i].y > ship.y && bombs[i].y < ship.y + ship.height) {
                     bombs[i].destroy();
                     bombs[i] = null;
-                    endGame(true);
+                    shipHit();
                     break;
                 }
             }
@@ -332,6 +390,7 @@ function checkBombBunkerCollision() {
                 if (Bunker1.checkBunkerHit(x, y, w, h)) {
                     bombs[i].destroy();
                     bombs[i] = null;
+                    continue;
                 }
             }
 
@@ -339,6 +398,7 @@ function checkBombBunkerCollision() {
                 if (Bunker2.checkBunkerHit(x, y, w, h)) {
                     bombs[i].destroy();
                     bombs[i] = null;
+                    continue;
                 }
             }
 
@@ -346,6 +406,7 @@ function checkBombBunkerCollision() {
                 if (Bunker3.checkBunkerHit(x, y, w, h)) {
                     bombs[i].destroy();
                     bombs[i] = null;
+                    continue;
                 }
             }
 
@@ -353,6 +414,7 @@ function checkBombBunkerCollision() {
                 if (Bunker4.checkBunkerHit(x, y, w, h)) {
                     bombs[i].destroy();
                     bombs[i] = null;
+                    continue;
                 }
             }
         }
